import { Authorization, AuthorizationStatus } from "../types/authorization";
import { Meta, UnitConfig, UnitResponse } from "../types/common";
import { BaseResource } from "./baseResource";
export declare class Authorizations extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    get(id: string, includeNonAuthorized?: boolean): Promise<UnitResponse<Authorization>>;
    find(params?: AuthorizationQueryParams): Promise<UnitResponse<Authorization[]> & Meta>;
}
export interface AuthorizationQueryParams {
    /**
     * Maximum number of resources that will be returned. Maximum is 1000 resources. [See Pagination](https://developers.unit.co/#intro-pagination).
     * default: 100
     */
    limit?: number;
    /**
     * Number of resources to skip.  [See Pagination](https://developers.unit.co/#intro-pagination).
     * default: 0
     */
    offset?: number;
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filters the results by the specified card id.
     * default: empty
     */
    cardId?: string;
    /**
     * Optional. Filters the Authorizations that occurred after the specified date. e.g. 2020-01-13T16:01:19.346Z
     */
    since?: string;
    /**
     * Optional. Filters the Authorizations that occurred before the specified date. e.g. 2020-01-02T20:06:23.486Z
     */
    until?: string;
    /**
     * Optional. Include authorizations from all statuses.
     */
    includeNonAuthorized?: boolean;
    /**
     * Optional. Filter authorizations by (Authorization Status)[https://docs.unit.co/cards-authorizations/#authorization-statuses].
     */
    status?: AuthorizationStatus;
    /**
     * Optional. Leave empty or provide sort=createdAt for ascending order. Provide sort=-createdAt (leading minus sign) for descending order.
     */
    sort?: string;
    /**
     * Optional. Filter result by their 4-digit ISO 18245 merchant category code (MCC).
     */
    merchantCategoryCode?: number[];
    /**
     * 	Optional. Filters the result that have an amount that is higher or equal to the specified amount (in cents). e.g. 5000
     */
    fromAmount?: number;
    /**
     * 	Optional. Filters the result that have an amount that is lower or equal to the specified amount (in cents). e.g. 7000
     */
    toAmount?: number;
}
