import { AuthorizationRequest, ApproveAuthorizationRequest, DeclineAuthorizationRequest } from "../types/authorizationRequest";
import { UnitResponse, UnitConfig } from "../types/common";
import { BaseResource } from "./baseResource";
export declare class AuthorizationRequests extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    get(id: string): Promise<UnitResponse<AuthorizationRequest>>;
    list(params?: AuthorizationRequestQueryParams): Promise<UnitResponse<AuthorizationRequest[]>>;
    approve(request: ApproveAuthorizationRequest): Promise<UnitResponse<AuthorizationRequest>>;
    decline(request: DeclineAuthorizationRequest): Promise<UnitResponse<AuthorizationRequest>>;
}
interface AuthorizationRequestQueryParams {
    /**
     * Maximum number of resources that will be returned. Maximum is 1000 resources. [See Pagination](https://developers.unit.co/#intro-pagination).
     * default: 100
     */
    limit?: number;
    /**
     * Number of resources to skip.  [See Pagination](https://developers.unit.co/#intro-pagination).
     * default: 0
     */
    offset?: number;
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter result by their 4-digit ISO 18245 merchant category code (MCC).
     */
    merchantCategoryCode?: number[];
    /**
     * 	Optional. Filters the result that have an amount that is higher or equal to the specified amount (in cents). e.g. 5000
     */
    fromAmount?: number;
    /**
     * 	Optional. Filters the result that have an amount that is lower or equal to the specified amount (in cents). e.g. 7000
     */
    toAmount?: number;
}
export {};
