import { Card, CardLimits, CreateDebitCardRequest, PinStatus, ReplaceCardRequest, UpdateCardRequest } from "../types/cards";
import { BaseListParams, Include, UnitConfig, UnitResponse } from "../types/common";
import { Customer } from "../types/customer";
import { Account } from "../types/account";
import { BaseResource } from "./baseResource";
export declare class Cards extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    createDebitCard(request: CreateDebitCardRequest): Promise<UnitResponse<Card>>;
    reportStolen(id: string): Promise<UnitResponse<Card>>;
    reportLost(id: string): Promise<UnitResponse<Card>>;
    closeCard(id: string): Promise<UnitResponse<Card>>;
    freeze(id: string): Promise<UnitResponse<Card>>;
    unfreeze(id: string): Promise<UnitResponse<Card>>;
    replace(request: ReplaceCardRequest): Promise<UnitResponse<Card>>;
    /**
     * @param id
     * @param include - Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account. See [Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources).
     */
    get(id: string, include?: string): Promise<UnitResponse<Card> & Include<Account[] | Customer[]>>;
    list(params?: CardListParams): Promise<UnitResponse<Card[]> & Include<Account[] | Customer[]>>;
    getPinStatus(id: string): Promise<UnitResponse<PinStatus>>;
    limits(id: string): Promise<UnitResponse<CardLimits>>;
    update(request: UpdateCardRequest): Promise<UnitResponse<Card>>;
}
export interface CardListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. A comma-separated list of related resources to include in the response. Related resources include: customer, account. See Getting Related Resources
     * default: empty
     */
    include?: string;
    /**
     * Optional. Filter customers by status (Active, Archived). Usage example: *filter[status][0]=Active
     */
    status?: string[];
    /**
     * Optional. Filter Applications by Tags.
     * default: empty
     */
    tags?: object;
    /**
     * Optional. sort=createdAt for ascending order or sort=-createdAt (leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: string;
}
