import { UnitResponse, UnitConfig, Meta, BaseListParams } from "../types/common";
import { Customer, PatchCustomerRequest, ArchiveCustomerRequest, AddAuthorizedUsersRequest, RemoveAuthorizedUsersRequest } from "../types/customer";
import { BaseResource } from "./baseResource";
export declare class Customers extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    update(request: PatchCustomerRequest): Promise<UnitResponse<Customer>>;
    get(customerId: string): Promise<UnitResponse<Customer>>;
    list(params?: CustomersListParams): Promise<UnitResponse<Customer[]> & Meta>;
    archiveCustomer(request: ArchiveCustomerRequest): Promise<UnitResponse<Customer>>;
    addAuthorizedUsers(request: AddAuthorizedUsersRequest): Promise<UnitResponse<Customer>>;
    removeAuthorizedUsers(request: RemoveAuthorizedUsersRequest): Promise<UnitResponse<Customer>>;
}
export interface CustomersListParams extends BaseListParams {
    /**
     * Optional. Search term according to the Full-Text Search Rules.
     * default: empty
     */
    query?: string;
    /**
     * Optional. Filter customers by email address (case sensitive).
     * default: empty
     */
    email?: string;
    /**
     * Optional. Filter customers by Tags.
     * default: empty
     */
    tags?: object;
    /**
     * Optional. Filter customers by status (Active, Archived). Usage example: *filter[status][0]=Active
     */
    status?: string[];
    /**
     * Optional. sort=createdAt for ascending order or sort=-createdAt (leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: string;
}
