import { BaseResource } from "./baseResource";
import { BaseListParams, Meta, UnitConfig, UnitResponse } from "../types/common";
import { CreateRecurringPaymentRequest, RecurringPayment } from "../types/recurringPayment";
export declare class RecurringPayments extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    create(request: CreateRecurringPaymentRequest): Promise<UnitResponse<RecurringPayment>>;
    disable(paymentId: string): Promise<UnitResponse<RecurringPayment>>;
    enable(paymentId: string): Promise<UnitResponse<RecurringPayment>>;
    get(paymentId: string): Promise<UnitResponse<RecurringPayment>>;
    list(params?: RecurringPaymentListParams): Promise<UnitResponse<RecurringPayment[]> & Meta>;
}
export interface RecurringPaymentListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter Applications by Tags.
     * default: empty
     */
    tags?: object;
    /**
     * Optional. Filter recurring payments by status (Active, Completed or Disabled). Usage example: *filter[status][0]=Active
     */
    status?: string[];
    /**
     * Optional. Filter recurring payments by Recurring Payment type. such as (RecurringCreditAchPayment, RecurringCreditBookPayment). Usage example: filter[type][0]=RecurringCreditAchPayment&filter[type][1]=RecurringCreditBookPayment
     */
    type?: string[];
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. Filters the Recurring Payments that their start time occurred after the specified date. e.g. 2022-06-13
     */
    fromStartTime?: string;
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. Filters the Recurring Payments that their start time occurred before the specified date. e.g. 2022-05-13
     */
    toStartTime?: string;
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. Filters the Recurring Payments that their end time occurred after the specified date. e.g. 2022-06-13
     */
    fromEndTime?: string;
    /**
     * RFC3339 format. For more information: https://en.wikipedia.org/wiki/ISO_8601#RFCs
     * Optional. Filters the Recurring Payments that their end time occurred before the specified date. e.g. 2022-05-13
     */
    toEndTime?: string;
    /**
     * Optional. Leave empty or provide sort = createdAt for ascending order.Provide sort = -createdAt(leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: string;
}
