"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const unit_1 = require("../unit");
const dotenv_1 = __importDefault(require("dotenv"));
const helpers_1 = require("../helpers");
const testHelpers_1 = require("./testHelpers");
dotenv_1.default.config();
const unit = new unit_1.Unit(process.env.UNIT_TOKEN || "test", process.env.UNIT_API_URL || "test");
const accountsId = [];
describe("Accounts List", () => {
    test("Get Accounts List", async () => {
        const res = await unit.accounts.list();
        res.data.forEach(element => {
            expect(element.type === "batchAccount" || element.type === "depositAccount").toBeTruthy();
            accountsId.push(element.id);
        });
        accountsId.forEach(async (id) => {
            const res = await unit.accounts.get(id);
            expect(res.data.type === "depositAccount" || res.data.type === "batchAccount").toBeTruthy();
        });
    });
});
describe("Create Account", () => {
    test("Create Deposit Account", async () => {
        const res = await (0, testHelpers_1.createIndividualAccount)(unit);
        const account = await unit.accounts.get(res.data.id);
        expect(account.data.type === "depositAccount").toBeTruthy();
    });
});
describe("Add Account Owners", () => {
    test("add account owners", async () => {
        var _a, _b, _c;
        const new_account = (await (0, testHelpers_1.createIndividualAccount)(unit)).data;
        const originated_customer_id = (_a = new_account.relationships.customer) === null || _a === void 0 ? void 0 : _a.data.id;
        const customer_id1 = await (0, testHelpers_1.createIndividualCustomer)(unit);
        const customer_id2 = await (0, testHelpers_1.createIndividualCustomer)(unit);
        let req = {
            accountId: new_account.id,
            data: (0, helpers_1.createRelationshipArray)("customer", [customer_id1, customer_id2])
        };
        const account = await unit.accounts.addOwners(req);
        let da = account.data;
        expect(da.type === "depositAccount").toBeTruthy();
        expect(da.relationships.customers).toBeDefined();
        (_b = da.relationships.customers) === null || _b === void 0 ? void 0 : _b.data.forEach(o => {
            expect([customer_id1, customer_id2, originated_customer_id].includes(o.id)).toBeTruthy();
        });
        req = {
            accountId: account.data.id,
            data: (0, helpers_1.createRelationshipArray)("customer", [customer_id1])
        };
        const a = await unit.accounts.removeOwners(req);
        da = a.data;
        expect(da.type === "depositAccount").toBeTruthy();
        expect(da.relationships.customers).toBeDefined();
        (_c = da.relationships.customers) === null || _c === void 0 ? void 0 : _c.data.forEach(o => {
            expect([customer_id2, originated_customer_id].includes(o.id)).toBeTruthy();
        });
    });
});
