"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCounterpartyForTest = void 0;
const unit_1 = require("../unit");
const dotenv_1 = __importDefault(require("dotenv"));
dotenv_1.default.config();
const unit = new unit_1.Unit(process.env.UNIT_TOKEN || "test", process.env.UNIT_API_URL || "test");
const counterpartiesId = [];
function createCounterpartyForTest(id) {
    const req = {
        "type": "achCounterparty",
        "attributes": {
            "name": "Joe Doe",
            "routingNumber": "123456789",
            "accountNumber": "123",
            "accountType": "Checking",
            "type": "Person"
        },
        "relationships": {
            "customer": {
                "data": {
                    "type": "customer",
                    "id": id
                }
            }
        }
    };
    return unit.counterparties.create(req);
}
exports.createCounterpartyForTest = createCounterpartyForTest;
describe("Counterparties List", () => {
    test("Get Counterparties List", async () => {
        const res = await unit.counterparties.list();
        res.data.forEach(element => {
            expect(element.type === "achCounterparty").toBeTruthy();
            counterpartiesId.push(element.id);
        });
    });
});
describe("Get Counterparty Test", () => {
    test("get each counterparty", async () => {
        counterpartiesId.forEach(async (id) => {
            const res = await unit.counterparties.get(id);
            expect(res.data.type === "achCounterparty").toBeTruthy();
        });
    });
});
describe("Create Counterparty", () => {
    test("create achCounterparty", async () => {
        const createRes = await createCounterpartyForTest("22605");
        const res = await unit.counterparties.get(createRes.data.id);
        expect(res.data.type === "achCounterparty").toBeTruthy();
    });
});
describe("Delete Counterparty", () => {
    test("delete achCounterparty", async () => {
        const createRes = await createCounterpartyForTest("22605");
        const res = await unit.counterparties.get(createRes.data.id);
        expect(res.data.type === "achCounterparty").toBeTruthy();
        const deleteRes = await unit.counterparties.delete(res.data.id);
        expect(deleteRes === "").toBeTruthy(); // NoContent
    });
});
